# Release information about gibe

version = "0.10.8"

description = "Blog using TurboGears with popular replacement components"
long_description = """TurboGears-based web log supporting multiple web logs on a single instance, using Genshi, SQLAlchemy, and Routes, and a plugin architecture."""
author = "Neil Blakey-Milner, et al"
email = "nbm@nxsy.org, gibe-developers@googlegroups.com" 
copyright = "2006-2007, Neil Blakey-Milner"

# if it's open source, you might want to specify these
url = "http://code.google.com/p/gibe/"
download_url = "http://code.google.com/p/gibe/downloads/list"
license = "BSD"
