<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude"
      py:strip="">

<xi:include href="utils.html"><xi:fallback/></xi:include>

<head py:match="head" py:attrs="select('@*')">

    <meta content="text/html; charset=UTF-8" http-equiv="content-type" py:replace="''"/>
    <title py:replace="''">Your title goes here</title>

    <link py:for="css in tg_css" py:replace="tg.ET(css.display())" />
    <link py:for="js in tg_js_head" py:replace="tg.ET(js.display())" />
    <link rel="stylesheet" href="${tg.url('/static/css/200701-01.css')}" type="text/css" />

    <meta py:replace="select('*')"/>
</head>

<body py:match="body" py:attrs="select('@*')">
    <div py:for="js in tg_js_bodytop" py:replace="tg.ET(js.display())" />

    <div id="wrapper">
      <div id="header">
        &nbsp; <!-- Hello Genshi, please don't close me improperly...  -->
      </div> <!-- #header -->
      <div id="pagebody">
        <div id="leading">

          <div py:if="tg_flash" class="flash" py:content="tg_flash"></div>

          <div py:replace="select('*|text()')"/>

        </div> <!-- #leading -->

        <div id="sidebar">
          
          <xi:include href="sidebar.html">
          </xi:include>

        </div> <!-- sidebar -->
      </div> <!-- #pagebody -->

      <div id="footer">
          <xi:include href="footer.html">
          </xi:include>
      </div> <!-- #footer -->
    </div> <!-- #wrapper -->

    <div py:for="js in tg_js_bodybottom" py:replace="tg.ET(js.display())" />

</body>

</html>
