<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">
<xi:include href="master.html" />

<head>
    <meta content="text/html; charset=UTF-8" http-equiv="content-type" py:replace="''"/>
    <title>Write a new post - <span py:replace="blog.name">Ponies!!1!one!</span> - <span py:replace="blog.owner.name">Sara Swift</span></title>
</head>

<body>
  <h2>Write a post</h2>
  <div py:content="tg.ET(post_form.display(action=tg.url_for('newpost'),
  theme='simple', value=post_form_values, **post_form_params))">Form is
  here...</div>
</body>
</html>
