<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<div xmlns="http://www.w3.org/1999/xhtml" xmlns:py="http://genshi.edgewall.org/" py:strip="">
          <!-- {{{ photos -->
          <div id="photos">
            <!-- <h2>Photos</h2> --> &nbsp;
          </div>
          <!-- }}} -->

           <!-- {{{ me -->
          <div id="me">
            <h2>About the author...</h2>

            <p>My name is Neil Blakey-Milner, and I am a open source
            developer and advocate, <a href="/nbm/" title="About
            Neil">amongst other things</a>.  I have <a
            href="/resume/">worked</a> at some interesting companies, <a
            href="/writings/">talked</a> at some interesting
            conferences, <a href="/engal/">taken photos</a> of some
            interesting people and places, and even <a
            href="/code/">written code</a> in some interesting
            languages.</p>

            <p>Yeah, I do lots of things with interesting stuff.</p>

            <p>You can decide for yourself if I write about interesting
            stuff on my weblog, <a href="/">Cosmic Seriosity
            Balance</a>.</p>
          </div>
          <!-- }}} -->

          <!-- {{{ contact -->
          <div id="contact">

            <h2>Contact me</h2>
            <ul class="booklist">
              <li>
                <img src="http://mithrandr.moria.org/images/email.png" width="154" height="12" border="0" />
              </li>
              <li> Jabber: nbm@jabber.obsidian.co.za </li>
            </ul>

          </div>
          <!-- }}} -->

          <!-- {{{ links -->
          <div id="links">

            <a href="http://park.clug.org.za/"><img src="${tg.url('/static/images/nbmclugpark.png')}" height="113" width="75" align="left" /></a>

            <h2>Elsewhere...</h2>

            <p>The image opposite is supposed to be me on <a href="http://park.clug.org.za/">CLUG
            Park</a>, the aggregator of the blogs of my local LUG members.</p>

            <p>You can also check <a href="/planet/">my aggregator</a> of the blogs
            I follow.</p>

          </div>
          <!-- }}} -->
</div>
