<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">
<xi:include href="master.html" />

<head>
    <meta content="text/html; charset=UTF-8" http-equiv="content-type" py:replace="''"/>
    <title>Items tagged with <span py:content="tag.name" py:strip="True">Tag name</span> - <span py:content="blog.name" py:strip="True">Blog name</span></title>
</head>

<body>
    <ul>
      <li py:for="post in posts" class="item">

      <p><a py:attrs="dict(href=tg.url_for('posts', post=post))" class="bookmark"
        title="Permalink to this entry." py:content="post.title">And so
        it begins...</a>
        <span py:if="len(post.comments)">
          (<span py:content="len(post.comments)">2</span> comments: 
            <span py:strip="True" py:for="comment in post.comments" py:if="comment.approved"><span
            py:content="tg.ET(comment.getReference())" py:strip="True">Foo</span> &hellip;
            </span> )
        </span></p>

        <p py:content="HTML(post.excerpt)">Well, one day, I got a little
        pony...</p>
      </li>
    </ul>
</body>
</html>
