/* Browser equality... */

* {
	margin: 0;
	padding: 0;
}
body {
	background: #514B6E;
	font-size: 76%;
}
ul, ol {
	padding-left: 1em;
	margin-left: 0px;
}

h1, h2, h3, h4, h5, h6, p, blockquote,
 form, label, ul, ol, dl, fieldset, address {
	margin-bottom: 1em;
}

blockquote {
    background-color: #fef;
    border-left: 1px solid #333;
    padding: 0.8em;
    font-style: italic;
}

/* Yay forms! */
table, td, th, input, label {
	font-size: 1em;
}

/* Who decided images should ever have borders? */
a img { border: none; }


/* The joys of "semantic" HTML... */
#wrapper {
	width: 960px;
	position: relative;
}

#pagebody {
	background: white;
	float: left;
	width: 100%;
	border: 2px solid #847EA5;
	margin-left: 1em;
	color: #333333;
}

/* headings */

#pagebody h1 {
	font-size: 2em;
	line-height: 1.1em;
	margin: 0.5em 0;
}
#pagebody h2 {
	font-size: 1em;
	line-height:1.2em;
	margin: 1.2em 0;
	color: #999988;
	text-align: right;
}
#pagebody h3 {
	font-size: 1.5em;
	line-height: 1.2em;
	margin: 0.6em 0;
	color: #705060;
}

#pagebody p {
	font-size: 1.1em;
	margin:0.7em 0;
}

/* links */
#leading a:link, #leading a:visited {
	color: #2065cc;
	text-decoration: none;
}

#leading a:hover {
	color: #C42B75;
}

#sidebar a:link, #sidebar a:visited {
	color:#ff8a42;
	text-decoration: none;
}
#sidebar a:hover { color:#2ad49a; }


/* FOOTER */
#footer {
	clear:both; 
	margin-left: 1em;
	padding-left: 1px;
	padding-top: 0.2em;
	width: 960px;
}
#footer a:link, #footer a:visited {
	color:white;
}
#footer a:hover {
	color:#D3FF99;
}

#footer #google {
	float: right;
	padding-top: 0.2em;
}
#footer #google font {
	font-size: 0.8em;
}
#footer #google input {
	font-size: 0.8em;
}

#footer #pageLogin {
	clear: both;
	text-align: center;
}

/* Sidebar */
#sidebar #photos {
	height: 125px;
	width: 320px;
	background: url(../images/107-320.jpg);
}
#sidebar #photos h2 {
	color:white;
	margin-right: 24px;
	margin: 0;
	padding-top: 1.2em;
}

#sidebar #me, #sidebar #contact {
	background: #6357A5;
}
#sidebar #links img {
	padding-right: 1em;
	padding-top: 0.5em;
	padding-bottom: 0.5em;
}

#sidebar #links, #sidebar #me, #sidebar #contact, #sidebar #links {
	font-size: 1em;
	padding: 0.1em 18px 18px 18px;
}

/* defaults */
#pagebody {
	background-color: #301040;
	background-image: url(../images/bg-640.png);
	background-repeat: repeat-y;
}
#pagebody #leading { 
	float:left; 
	clear:left;
	width: 640px; 
}
#pagebody #sidebar {
	float:right;
	width:320px;
	color: #fff;
}
#pagebody #sidebar {
	margin: 0px;
	padding: 0px;
	margin: 0px;
}

#posts {
	background: white;
}
#posts2 {
	background-color: #FFDDFF;
	font-size:1em;
	padding: 0.1em 3px 3px 3px;
}

#post #blogmain { background: white; padding-bottom: 2em; }
#post .postcontent { padding: 1em 2em; }
#post H1 {
    background: #dbf;
    border-bottom: 2px solid #a7a;
    border-right: 2px solid #a7a;
    color: #252;
    /* margin: 0 0 0.2em 0; */
    margin: 0px;
    padding: 2px 5px;
}
h5.date { border: 0px; margin: 0px; padding: 0px; width: 25em; text-align: right}
#post .categories { background-color: #CCFFCC; color: #005500; font-weight: lighter; margin-bottom: 1em;}
/* #post .blog_add_comment { text-align: center; padding: 1em; margin-top: 1em; } */
#post .blog_add_comment th { padding: 0.5em 1em; text-align: left; }
#post .blog_comments { padding: 0.5em; }
#post div.blogcomment { background-color: #fcf9ff; border: 1px solid #ccc; margin-top: 1em; padding: 1em; }

.posted { margin-top: 1.5em; }


.gibe_comment_unapproved { background-color: #fdd; }
.gibe_admin_post_comments { border: 0; margin: 0; padding: 0; }
.gibe_admin_post_comments td { padding: 0.2em; }
.gibe_admin_post_comments_start { border-top: 1px solid gray; }
.gibe_admin_post_comments_end td { border-bottom: 1px solid gray; padding-bottom: 0.4em; margin-bottom: 1em; }

#frontpage #mainpost { background: white; padding: 1em 2em; font-size: 1.1em;}
#frontpage #otherposts { padding: 1em 2em; }
#frontpage #otherposts h2 { padding: 1em 2em;}
#frontpage #mainpost .posttitle { font-size: 1.2em; font-weight: bold;}
#frontpage #otherposts .post .posttitle { font-size: 1.2em; font-weight: bold;}

#archives #posts { background: white; padding: 1em 2em; font-size: 1.1em;}
#archives #posts .categories { color: #999; font-size: 0.8em; }
#archives #posts .categories a:link, #archives #posts .categories a:visited { color: #559; }

#frontpage .categories { color: #999; font-size: 0.8em; }
#frontpage .categories a:link, #archives #posts .categories a:visited { color: #559; }

.pagination { text-align: center; border: 1px solid gray; background: #faf0ff; padding: 1em; margin: 1em; }

.dp-highlighter { font-size: 0.85em; }

#post .post_top_widgets { padding: 0em 1em; }

.readon { text-align: right; font-size: 0.9em; }
hr.excerpt { display: none; }
