<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<div xmlns="http://www.w3.org/1999/xhtml" xmlns:py="http://genshi.edgewall.org/" py:strip="">
        <!-- {{{ google -->
        <div id="google">
          <!-- SiteSearch Google -->
          <form method="get" action="http://www.google.com/custom" target="_top">
          <input type="radio" name="sitesearch" value="" checked="checked" id="ss0"></input>
          <label for="ss0" title="Search the Web"><font size="-1"
          color="#ffffff">Web</font></label>
          <input type="radio" name="sitesearch" value="nxsy.org" id="ss1"></input>
          <label for="ss1" title="Search nxsy.org"><font size="-1"
          color="#ffffff">nxsy.org</font></label>

          <input type="hidden" name="domains" value="nxsy.org"></input>
          <label for="sbi" style="display: none">Enter your search terms</label>
          <input type="text" name="q" size="20" maxlength="255" value=""
          id="sbi"></input>
          <label for="sbb" style="display: none">Submit search form</label>
          <input type="submit" name="sa" value="Google Search" id="sbb"></input>
          <input type="hidden" name="client" value="pub-5046275896387552"></input>
          <input type="hidden" name="forid" value="1"></input>
          <input type="hidden" name="ie" value="ISO-8859-1"></input>
          <input type="hidden" name="oe" value="ISO-8859-1"></input>
          <input type="hidden" name="cof"
          value="GALT:#008000;GL:1;DIV:#336699;VLC:663399;AH:center;BGC:FFFFFF;LBGC:336699;ALC:0000FF;LC:0000FF;T:000000;GFNT:0000FF;GIMP:0000FF;FORID:1"></input>
          <input type="hidden" name="hl" value="en"></input>
          </form>
          <!-- SiteSearch Google -->
        </div>
        <!-- }}} -->

        <a href="/copyright">&copy; Neil Blakey-Milner, 2000-2007</a>

        <!-- <p align="center"><img src="${tg.url('/static/images/tg_under_the_hood.png')}" alt="TurboGears under the hood"/></p> -->

        <!-- {{{ pageLogin -->
        <div py:if="tg.config('identity.on',False) and not logging_in" id="pageLogin" py:choose="">
          <span py:when="tg.identity.anonymous">
            <a href="${tg.url_for('login')}">Login</a>
          </span>
          <span py:otherwise="">
            <!-- Welcome ${tg.identity.user.display_name}.<br /> -->
            <span py:if="'admin' in tg.identity.groups">
              <a href="${tg.url_for('writepost')}">Write post</a> |
              <a href="${tg.url_for('admin')}">Manage</a> |
            </span>
            <a href="${tg.url_for('logout')}">Logout</a>
          </span>
        </div> <!-- #pageLogin -->
        <!-- }}} -->
</div>
