* { margin: 0; padding: 0; }
HTML {margin:0;padding:0;}
BODY {margin: 1em 2em; padding: 0;}

#pageContainer {
    border: none;
    border-bottom: 1px solid #aaa;
    margin: 0;
    min-width: 750px;
}

BODY #header {
    background-image: url(capepoint-seawater3.png);
    background-position: top left;
    background-repeat: no-repeat;
    background-color: #9fdfe2;
    height: 80px;
}

#leftColumn DIV.imageandcaption {
    text-align: center;
    width: 64px;
    border: 1px solid #aac;
    padding: 0;
    margin: 0;
    margin-bottom: 0.5em;
}

#leftColumn DIV.imageandcaption IMG {
    border: 0;
    border-bottom: 1px solid #aac;
    padding: 0;
    margin: 0;
}

#leftColumn DIV.imageandcaption P {
    font-size: 65%;
    padding: 0;
    margin: 0;
    line-height: 1;
}

#leftColumn DIV.imageandcaption A {
    text-decoration: none;
}

#leftColumn DIV.imageandcaption A:hover {
    text-decoration: underline;
}

BODY #pageContent {
    border: none;
    margin-left: 85px;
}

BODY #middleContainer {
    margin-right: 16em;
    border-right: 0.1em solid #f5eeff;
    border-left: 0.1em solid #f5eeff;
    position: relative;
}

BODY #leftAndMiddleColumns {
    float: left;
    display: inline;
    position: relative;
    width: 100%;
}

BODY #middleColumn {
    float: right;
    display: inline;
    position: relative;
    width: 100%;
}

BODY #leftColumn {
    float: left;
    display: inline;
    position: relative;
    width: 85px;
    margin-left: -87px;
}

BODY #rightColumn {
    display: inline;
    float: right;
    margin-left: 0.1em;
    margin-right: -16.1em;
    position: relative;
    width: 16em;
}

BODY {
    background-color: #fff;
    color: #111;
}

BODY #pageContent {
    border-left-color: #f5eeff;
    border-right-color: #f5eeff;
}

BODY #pageContentContainer {
    background-color: transparent;
    background-image: none;
}

BODY #pageContent {
    background-color: transparent;
    background-image: none;
}

BODY #masthead {
    border-top: none;
}

BODY #middleColumn {
    padding: 0.2em 0;
    font-size: 90%;
}

BODY DIV.middleBox {
    margin: 0 0.2em 0.2em 0.2em;
    margin-left: 0.75em;
    margin-right: 0.75em;
    padding: 0;
}

BODY #middleColumn H4 {
    background: #dbf;
    border-bottom: 2px solid #a7a;
    border-right: 2px solid #a7a;
    border-left: 2px solid #c9c;
    border-top: 2px solid #c9c;
    color: #252;
    margin: 0 0 0.2em 0;
    padding: 2px 5px;
}

BODY DIV.middleBox p {
  margin: 0.5em 0.5em 0.5em 0.5em;
  line-height: 1.4;
}

BODY #leftColumn {
  padding: 0.2em 0;
}

BODY DIV.leftBox {
  border: 1px solid #99c;
  margin: 0 0.2em 0.2em 0.2em;
  padding: 0;
}

BODY DIV.leftBox p {
  line-height: 1.1;
  margin: 0 0.2em 0.4em 0.2em;
}

BODY #rightColumn {
  padding: .2em 0;
}

BODY DIV.rightBox {
  border: 0;
  margin: 0 0.2em 0.2em 0.2em;
  margin-left: 0.5em;
  padding: 0;
  font-size: 75%;
}

BODY DIV.rightBox H2 {
  text-align: center;
}

BODY DIV.rightBox p {
  line-height: 1.1;
  margin: 0 0.2em 0.4em 0.2em;
}

#tagcloud A { color: #5555cc; text-decoration: none; }
#tagcloud A:hover { border-bottom: 0.14em dashed #55f;}
#tagcloud .smallestTag { font-size: 60% }
#tagcloud .smallTag { font-size: 80% }
#tagcloud .mediumTag { font-size: 100% }
#tagcloud .bigTag { font-size: 105% }
#tagcloud .biggestTag { font-size: 120% }
#tagcloud .hugeTag { font-size: 135% }
#tagcloud .hugestTag { font-size: 150% }
#tagcloud .mostHugeTag { font-size: 165% }

BODY #middleColumn A.bookmark {
  color: #5555ff;
  font-size: 110%;
  font-weight: bold;
  text-decoration: none;
  border-bottom: thin dashed #55F;
}

BODY #middleColumn A {
  color: #5555ff;
  font-size: 85%;
  font-weight: bold;
  text-decoration: none;
  border-bottom: thin dashed #55f;
}

#pageContainer:after,
#pageContentContainer:after,
#pageContent:after,
#middleContainer:after,
#leftAndMiddleColumns:after,
#leftAndMiddleColumns:after,
.middleBox:after {
  clear: both          !important;
  content: "..."       !important;
  display: block       !important;
  font-size: 1px       !important;
  height: 0            !important;
  overflow: hidden     !important;
  visibility: hidden   !important;
}
.categories { background-color: #CCFFCC; color: #005500; font-weight: lighter; margin-bottom: 1em;}

    #framed { float: left;
              margin-top: 0;
              margin-right: 1em;
              clear: both; }

    #framed img { border: 1px solid #555555;
                  display: block; }

    .framed { float: left;
              margin-top: 1em;
              margin-right: 1em;
              clear: both; }

    .framed img { border: 1px solid #555555;
                  display: block; }

BODY #middleColumn H2.block {
    background: #dbf;
    border-bottom: 2px solid #a7a; border-right: 2px solid #a7a;
    border-left: 2px solid #c9c;
    border-top: 2px solid #c9c;
    color: #252;
    margin: 0 0 0.2em 0;
    padding: 2px 5px;
}

.posted { margin-top: 1.5em; }
.blogcomment div { background-color: #eef; border:1px solid #555555; margin-top: 1em; padding: 1em; }

LI.item { padding-top: 1em; }
UL > LI.item:first-child { padding-top: 0em; }

.navigation { border-top: 1px solid #eee; width: 100%; text-align: center; padding-top: 0.25em; margin-top: 2em;}
h5.date { border: 0px; margin: 0px; padding: 0px; width: 19em;}

BODY #middleColumn .mceEditorContainer A { border: 0; text-decoration: normal; }

.blog_add_comment { border-top: 1px solid #eee; width: 100%; text-align: center; padding-top: 1em; margin-top: 1em;}

.gibe_comment_unapproved { background-color: #fdd; }
.gibe_admin_post_comments { border: 0; margin: 0; padding: 0; }
.gibe_admin_post_comments td { padding: 0.2em; }
.gibe_admin_post_comments_start { border-top: 1px solid gray; }
.gibe_admin_post_comments_end td { border-bottom: 1px solid gray; padding-bottom: 0.4em; margin-bottom: 1em; }
