<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">
<xi:include href="master.html" />

<head>
    <meta content="text/html; charset=UTF-8" http-equiv="content-type" py:replace="''"/>
    <title>Archives - <span py:replace="blog.name">Ponies!!1!one!</span> - <span py:replace="blog.owner.display_name">Sara Swift</span></title>
</head>

<body id="archives">

  <div id="posts">

      <div class="pagination" py:if="tg.paginate.page_count > 1" />

      <div py:for="day, posts in tg.display_entries(posts)">
        <h2 py:content="day.strftime(str('%B %d, %Y'))">September 23, 2006</h2>

    <ul>
      <li py:for="post in posts" class="item">

      <p><a py:attrs="dict(href=tg.url_for('posts', post=post))" class="bookmark"
        title="Permalink to this entry." py:content="post.title">And so
        it begins...</a>
        <span py:if="len(post.comments)">
          (<span py:content="len(post.comments)">2</span> comments:
            <span class="commaise">
            <span py:strip="True" py:for="comment in post.comments" py:if="comment.approved"
            py:content="tg.ET(comment.getReference())">Some guy</span>
            </span>)

        </span></p>

      <div py:if="post_list_top_widgets" py:for="widget in post_list_top_widgets" class="post_list_top_widgets">
          <span py:replace="tg.ET(widget.display(post = post, blog = blog, post_url=tg.base_url, post_title=post.title, blog_name = blog.name, blog_rss = tg.url_for('rss2.0.xml')))" />
      </div>

        <p py:content="HTML(post.excerpt)">Well, one day, I got a little
        pony...</p>

        <p class="readon"><a href="${tg.url_for('posts', post=post)}">Read on...</a></p>

      <div py:if="post_list_bottom_widgets" py:for="widget in post_list_bottom_widgets" class="post_list_bottom_widgets">
          <span py:replace="tg.ET(widget.display(post = post, blog = blog, post_url=tg.base_url, post_title=post.title, blog_name = blog.name, blog_rss = tg.url_for('rss2.0.xml')))" />
      </div>

      </li>
    </ul>
    </div>
  </div>
</body>
</html>
