<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">
<xi:include href="master.html" />

<head>
    <meta content="text/html; charset=UTF-8" http-equiv="content-type" py:replace="''"/>
    <title><span py:replace="blog.name">Ponies!!1!one!</span> - <span py:replace="blog.owner.display_name">Sara Swift</span></title>
</head>

<body id="frontpage">
   <div id="mainpost" py:with="post=posts[0]">
       <h2 py:content="post.creation_time.strftime(str('%B %d, %Y'))">September 23, 2006</h2>

      <p><a py:attrs="dict(href=tg.url_for('posts', post=post))" class="posttitle"
        title="Permalink to this entry." py:content="post.title">And so
        it begins...</a>
        <span py:if="len(post.comments)">
          (<span py:content="len(post.comments)">2</span> comments: 
            <span class="commaise">
            <span py:strip="True" py:for="comment in post.comments" py:if="comment.approved"
            py:content="tg.ET(comment.getReference())">Some guy</span>
            </span> )
        </span></p>

<div class="categories" py:if="len(post.tags)">Categories: <span
class="commaise"><a
py:for="tag in post.tags" href="${tg.url_for('tags', tag=tag)}" rel="tag"
py:content="tag.display_name">me</a></span></div>

        <p py:content="HTML(post.excerpt)">Well, one day, I got a little
        pony...</p>

        <p class="readon"><a href="${tg.url_for('posts', post=post)}">Read on...</a></p>
   </div>


   <div id="otherposts" py:with="display_entries=tg.display_entries(posts[1:3])">
      <div py:for="day, day_posts in display_entries">
        <h2 py:content="day.strftime(str('%B %d, %Y'))">September 23, 2006</h2>

    <ul>
      <li py:for="post in day_posts" class="post">

      <p><a py:attrs="dict(href=tg.url_for('posts', post=post))" class="posttitle"
        title="Permalink to this entry." py:content="post.title">And so
        it begins...</a>
        <span py:if="len(post.comments)">
          (<span py:content="len(post.comments)">2</span> comments: 
            <span class="commaise">
            <span py:strip="True" py:for="comment in post.comments" py:if="comment.approved"
            py:content="tg.ET(comment.getReference())">Some guy</span>
            </span> )
        </span></p>

<div class="categories" py:if="len(post.tags)">Categories: <span
class="commaise"><a
py:for="tag in post.tags" href="${tg.url_for('tags', tag=tag)}"
py:content="tag.display_name">me</a></span></div>

        <p py:content="HTML(post.excerpt)">Well, one day, I got a little
        pony...</p>

        <p class="readon"><a href="${tg.url_for('posts', post=post)}">Read on...</a></p>
      </li>
    </ul>
    </div>
    <p><a href="${tg.url_for('archives')}">More posts >>></a></p>
  </div>
</body>
</html>
