<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">
<xi:include href="master.html" />

<head>
    <meta content="text/html; charset=UTF-8" http-equiv="content-type" py:replace="''"/>
    <title><span py:replace="post.title">My little pony</span> - <span py:replace="blog.name">Ponies!!1!one!</span> - <span py:replace="blog.owner.display_name">Sara Swift</span></title>
</head>

<body id="post">
  <div class="blog">
    <div class="blogbody">
      <div id="blogmain">
      <h1 class="title" py:content="post.title">My little pony</h1>
      <h5 class="date" style="float:right" py:content="post.creation_time.strftime(str('%A, %-d %B %Y at %I:%M %p'))">September 23, 2006</h5>

      <div py:if="post_top_widgets" py:for="widget in post_top_widgets" class="post_top_widgets">
          <span py:replace="tg.ET(widget.display(post = post, blog = blog, post_url=tg.base_url, post_title=post.title, blog_name = blog.name, blog_rss = tg.url_for('rss2.0.xml')))" />
      </div>

      <div py:content="HTML(post.content)" class="postcontent">Well, one day, I got a little
        pony...</div>

      <div py:if="post_bottom_widgets" py:for="widget in post_bottom_widgets" class="post_bottom_widgets">
          <span py:replace="tg.ET(widget.display(post = post, blog = blog, post_url=tg.base_url, post_title=post.title, blog_name = blog.name, blog_rss = tg.url_for('rss2.0.xml')))" />
      </div>

      <div class="blog_comments" py:if="len(post.comments)">

        <h3 class="title">Other thoughts</h3>
        
        <div class="blogcomment" py:for="comment in post.comments" py:if="comment.approved">
        <div id="au${comment.comment_id}">
        <p><span class="blog_comment_post_time" py:content="comment.posted_time.strftime(str('%B %d, %y %X'))">September 20, 2006 22:00</span> | <span class="reference" py:content="tg.ET(comment.getReference())"><a href="http://www.greenman.co.za/b2evolution/blogs/">Ian</a></span></p>
        <p py:content="HTML(comment.getContentHtml())">Any idea what the other three were using?</p>
        </div>
        </div>

      </div>

      </div>

      <div class="blog_add_comment" py:if="accept_comments"
      py:content="tg.ET(comment_form.display(action=tg.url_for('add_comment'),
      value=dict(postid=post.post_id)))" />

      <div class="navigation">
        <span py:if="previous_post" py:strip="True"><a py:attrs="dict(href=url_for('posts',
        post=previous_post))">&laquo; <span py:replace="previous_post.title">Picture of my
        pony!!one1</span></a> | </span> 
        <a href="" py:attrs="dict(href=url_for('frontpage'))" py:content="blog.name">Main</a>
        <span py:if="next_post" py:strip="True"> | <a py:attrs="dict(href=url_for('posts',
        post=next_post))"><span py:replace="next_post.title">Poem for my
        pony</span> &raquo;</a></span> 
      </div>


    </div>
  </div>

</body>
</html>
